# flake8: noqa

"""
    Institution Identifiers

    The Insitution Identifiers API provides a mapping between identifiers used in various University databases. The current known database namespaces are:  * `insts.lookup.cam.ac.uk` - [Lookup](https://www.lookup.cam.ac.uk/) instids. * `institution.v1.human-resources.university.identifiers.cam.ac.uk` -   identifiers used in the Human Resources (HR) database. * `institution.v1.student.university.identifiers.cam.ac.uk` - identifiers used   in the Student Information System (SIS) database.  The API provides a single endpoint which can be used to retrieve the current reports as a JSON document. For example, on a machine with [curl](https://curl.se/) installed:  ``` $ curl -o mapping.json https://api.apps.cam.ac.uk/institutions/mapping/v1 ```  The API is useful if you need to reconcile records drawn from multiple databases and determine which institutions are equivalent between them.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: devops@uis.cam.ac.uk
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from identitylib.inst_identifier_client.api_client import ApiClient

# import Configuration
from identitylib.inst_identifier_client.configuration import Configuration

# import exceptions
from identitylib.inst_identifier_client.exceptions import OpenApiException
from identitylib.inst_identifier_client.exceptions import ApiAttributeError
from identitylib.inst_identifier_client.exceptions import ApiTypeError
from identitylib.inst_identifier_client.exceptions import ApiValueError
from identitylib.inst_identifier_client.exceptions import ApiKeyError
from identitylib.inst_identifier_client.exceptions import ApiException
